"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGlobalScrollSpyOf = void 0;
const react_1 = require("react");
const GlobalScrollSpyContext_1 = require("./GlobalScrollSpyContext");
/**
 * @returns [ isActive, actions ] - Two return values are returned as an array
 * @returns isActive - Whether the DOM element specified by key is active
 * @returns actions - Actions are used to control registered DOM elements specified by key
 */
const useGlobalScrollSpyOf = (key) => {
    const { activeElement, actions } = (0, react_1.useContext)(GlobalScrollSpyContext_1.GlobalScrollSpyContext);
    const isActive = activeElement?.key === key;
    const registerElement = (0, react_1.useCallback)((element) => {
        actions.registerElement({ key, element });
    }, [actions, key]);
    const unregisterElement = (0, react_1.useCallback)(() => {
        actions.unregisterElement({ key });
    }, [actions, key]);
    return [isActive, { registerElement, unregisterElement }];
};
exports.useGlobalScrollSpyOf = useGlobalScrollSpyOf;
//# sourceMappingURL=useGlobalScrollSpyOf.js.map