import { useCallback, useContext } from "react";
import { GlobalScrollSpyContext } from "./GlobalScrollSpyContext";
/**
 * @returns [ isActive, actions ] - Two return values are returned as an array
 * @returns isActive - Whether the DOM element specified by key is active
 * @returns actions - Actions are used to control registered DOM elements specified by key
 */
export const useGlobalScrollSpyOf = (key) => {
    const { activeElement, actions } = useContext(GlobalScrollSpyContext);
    const isActive = activeElement?.key === key;
    const registerElement = useCallback((element) => {
        actions.registerElement({ key, element });
    }, [actions, key]);
    const unregisterElement = useCallback(() => {
        actions.unregisterElement({ key });
    }, [actions, key]);
    return [isActive, { registerElement, unregisterElement }];
};
//# sourceMappingURL=useGlobalScrollSpyOf.js.map